#ifndef _DCC_RECEIVER_H_INCLUDED_
#define _DCC_RECEIVER_H_INCLUDED_

//------------------------------------------------------------------------
//
// OpenDCC - DCC Packet Receiver Module
//
// Copyright (c) 2008 Alex Shepherd
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      DccRxIntTimer.c
// author:    Alex Shepherd
// webpage:   http://opendcc.sourceforge.net/
// history:   2008-01-23 (as) Initial Version based on Wolfgang Kufer's
//                             dcc_receiver.[hc] files 
//            2008-08-08 (kw) extended DCC_MESSAGE_SIZE to 13
// 
//------------------------------------------------------------------------
// credit:    This software is substantially based on work by
//            Wolfgang Kufer (kufer@gmx.de) His original project
//            can be found here: http://www.opendcc.de
//------------------------------------------------------------------------
//
// purpose:   This library module implement a DCC Packet Receiver that uses
//            an External Interrupt line INTx and a timer to decode DCC packets
//
//------------------------------------------------------------------------

#include <inttypes.h>

#include "config.h"

// #define MAX_DCC_MESSAGE_LEN 6    // including XOR-Byte - old definition
#define MAX_DCC_MESSAGE_LEN 13      // including XOR-Byte - new - to decode special railcom messages


// #define MSG_VALLD     (1<<0)
#define MSG_POLARITY  (1<<0)
#define MSG_RAILCOM   (1<<1)

typedef struct
  {
    uint8_t Qualifier ;                 // bitfield:
                                        // Bit x:  valid (this is currently not done by DccRx)
                                        // Bit 0:  polarity
                                        // Bit 1:  railcom detected
    uint8_t	Size ;                      // actual size of message (incl. XOR)
    uint8_t	PreambleBits ;              // cnt of preamble (at least 10)
    uint8_t Data[MAX_DCC_MESSAGE_LEN] ;
  } DCC_MSG ;

void initDccRx(void);

uint8_t getDccRxMsg( DCC_MSG * pBuf ) ;

// System 100us Timer Support
// uint8_t getSysTicksDelta(void) ;
// void initSysTicks(void) ;

void watch_railcom(void);               // temp call to check out railcom feedback

#endif
